Showimg
=======

Show image on 256-coloured terminal.


Installation and Usage
----------------------

.. code-block:: console

   $ pip install --user showimg
   $ showimg <Image url>

   # Or get random cat image.
   $ showimg --cat
